==> eiffelstudio-18.11.10.2592.tar: F_code/C6/ew299.c <==
/*
 * Code for class EW_NAMED_EIFFEL_TEST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew299.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_NAMED_EIFFEL_TEST}.make */
void F892_6101 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLR(4,arg4);
	RTLR(5,arg5);
	RTLIU(6);
	
	RTEAA("make", 891, Current, 0, 5, 12290);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg2;
	RTHOOK(3);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg3;
	RTHOOK(4);
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) arg4;
	RTHOOK(5);
	RTAR(Current, arg5);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) arg5;
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {EW_NAMED_EIFFEL_TEST}.execute */
void F892_6102 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,loc1);
	RTLR(5,tr3);
	RTLIU(6);
	
	RTEAA("execute", 891, Current, 1, 1, 12291);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(4043,F717_4043,(Current));
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F631_3562(RTCW(arg1), tr1, tr2);
	RTHOOK(2);
	tr1 = RTLNS(eif_new_type(895, 0x00).id, 895, _OBJSIZ_10_4_0_1_0_0_0_0_);
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	tr3 = RTOSCF(6048,F890_6048,(Current));
	F896_6146(RTCW(tr1), tr2, NULL, tr3, (EIF_BOOLEAN) 1);
	loc1 = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	F896_6151(RTCW(loc1), arg1);
	RTHOOK(4);
	tr1 = *(EIF_REFERENCE *)(RTCW(loc1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(5);
	tb1 = *(EIF_BOOLEAN *)(RTCW(loc1)+ _CHROFF_10_0_);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_) = (EIF_BOOLEAN) tb1;
	RTHOOK(6);
	tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_1_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(7);
	RTLE;
	RTEE;
}

/* {EW_NAMED_EIFFEL_TEST}.last_test */
EIF_REFERENCE F892_6103 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {EW_NAMED_EIFFEL_TEST}.errors */
EIF_REFERENCE F892_6105 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {EW_NAMED_EIFFEL_TEST}.test_name */
EIF_REFERENCE F892_6106 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {EW_NAMED_EIFFEL_TEST}.full_source_directory */
EIF_REFERENCE F892_6107 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {EW_NAMED_EIFFEL_TEST}.last_source_directory_component */
EIF_REFERENCE F892_6108 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {EW_NAMED_EIFFEL_TEST}.test_control_file_name */
EIF_REFERENCE F892_6109 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_5_);
}


/* {EW_NAMED_EIFFEL_TEST}.keywords */
EIF_REFERENCE F892_6110 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


/* {EW_NAMED_EIFFEL_TEST}.has_keyword */
EIF_BOOLEAN F892_6111 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("has_keyword", 891, Current, 0, 1, 12282);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	F342_2830(RTCW(tr1));
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R2511[Dtype(tr1)-504])(RTCW(tr1));
	RTHOOK(3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2517[Dtype(tr1)-365])(RTCW(tr1), arg1);
	RTHOOK(4);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	Result = F366_2847(RTCW(tr1));
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) !Result;
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_NAMED_EIFFEL_TEST}.manual_execution_required */
EIF_BOOLEAN F892_6114 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("manual_execution_required", 891, Current, 0, 0, 12285);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(6117,F892_6117,(Current));
	Result = F892_6111(Current, tr1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_NAMED_EIFFEL_TEST}.skip_requested */
EIF_BOOLEAN F892_6115 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("skip_requested", 891, Current, 0, 0, 12286);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(6118,F892_6118,(Current));
	Result = F892_6111(Current, tr1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_NAMED_EIFFEL_TEST}.execution_allowed */
EIF_BOOLEAN F892_6116 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("execution_allowed", 891, Current, 0, 0, 12287);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	if ((EIF_BOOLEAN) !F892_6114(Current)) {
		Result = (EIF_BOOLEAN) !F892_6115(Current);
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_NAMED_EIFFEL_TEST}.manual_keyword */

EIF_REFERENCE F892_6117 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (6117,RTMS32_EX_H("m\000\000\000a\000\000\000n\000\000\000u\000\000\000a\000\000\000l\000\000\000",6,2068234092));
}

/* {EW_NAMED_EIFFEL_TEST}.skip_keyword */

EIF_REFERENCE F892_6118 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (6118,RTMS32_EX_H("s\000\000\000k\000\000\000i\000\000\000p\000\000\000",4,1936419184));
}

void EIF_Minit299 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C6/ew299.c <==
/*
 * Code for class EW_NAMED_EIFFEL_TEST
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew299.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_NAMED_EIFFEL_TEST}.make */
void F892_6122 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4, EIF_REFERENCE arg5)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,arg2);
	RTLR(3,arg3);
	RTLR(4,arg4);
	RTLR(5,arg5);
	RTLIU(6);
	
	RTEAA("make", 891, Current, 0, 5, 12315);
	RTGC;
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) arg1;
	RTHOOK(2);
	RTAR(Current, arg2);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg2;
	RTHOOK(3);
	RTAR(Current, arg3);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) arg3;
	RTHOOK(4);
	RTAR(Current, arg4);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) arg4;
	RTHOOK(5);
	RTAR(Current, arg5);
	*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) arg5;
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {EW_NAMED_EIFFEL_TEST}.execute */
void F892_6123 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(5);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,tr1);
	RTLR(3,tr2);
	RTLR(4,loc1);
	RTLIU(5);
	
	RTEAA("execute", 891, Current, 1, 1, 12316);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(4050,F717_4050, (Current));
	tr2 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F631_3569(RTCW(arg1), tr1, tr2);
	RTHOOK(2);
	loc1 = RTLNS(eif_new_type(895, 0x00).id, 895, _OBJSIZ_10_4_0_1_0_0_0_0_);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_5_);
	tr2 = RTOSCF(6069,F890_6069, (Current));
	F896_6167(RTCW(loc1), tr1, NULL, tr2, (EIF_BOOLEAN) 1);
	RTHOOK(3);
	F896_6172(RTCW(loc1), arg1);
	RTHOOK(4);
	tr1 = *(EIF_REFERENCE *)(RTCW(loc1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(5);
	tb1 = *(EIF_BOOLEAN *)(RTCW(loc1)+ _CHROFF_10_0_);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_7_0_) = (EIF_BOOLEAN) tb1;
	RTHOOK(6);
	tr1 = *(EIF_REFERENCE *)(RTCW(loc1) + _REFACS_1_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(7);
	RTLE;
	RTEE;
}

/* {EW_NAMED_EIFFEL_TEST}.has_keyword */
EIF_BOOLEAN F892_6132 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg1);
	RTLIU(3);
	
	RTEAA("has_keyword", 891, Current, 0, 1, 12325);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	F342_2832(RTCW(tr1));
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	(FUNCTION_CAST(void, (EIF_REFERENCE)) R2513[Dtype(RTCW(tr1))-531])(tr1);
	RTHOOK(3);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_REFERENCE)) R2519[Dtype(RTCW(tr1))-505])(tr1, arg1);
	RTHOOK(4);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_6_);
	Result = F366_2849(RTCW(tr1));
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) !Result;
	RTHOOK(5);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_NAMED_EIFFEL_TEST}.manual_execution_required */
EIF_BOOLEAN F892_6135 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("manual_execution_required", 891, Current, 0, 0, 12328);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(6138,F892_6138, (Current));
	Result = F892_6132(Current, tr1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_NAMED_EIFFEL_TEST}.skip_requested */
EIF_BOOLEAN F892_6136 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("skip_requested", 891, Current, 0, 0, 12329);
	RTGC;
	RTHOOK(1);
	tr1 = RTOSCF(6139,F892_6139, (Current));
	Result = F892_6132(Current, tr1);
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_NAMED_EIFFEL_TEST}.execution_allowed */
EIF_BOOLEAN F892_6137 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("execution_allowed", 891, Current, 0, 0, 12330);
	RTGC;
	RTHOOK(1);
	Result = '\0';
	if ((EIF_BOOLEAN) !F892_6135(Current)) {
		Result = (EIF_BOOLEAN) !F892_6136(Current);
	}
	RTHOOK(2);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_NAMED_EIFFEL_TEST}.manual_keyword */

EIF_REFERENCE F892_6138 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (6138,RTMS32_EX_H("m\000\000\000a\000\000\000n\000\000\000u\000\000\000a\000\000\000l\000\000\000",6,2068234092));
}

/* {EW_NAMED_EIFFEL_TEST}.skip_keyword */

EIF_REFERENCE F892_6139 (EIF_REFERENCE Current)
{
	GTCX
	RTOSC (6139,RTMS32_EX_H("s\000\000\000k\000\000\000i\000\000\000p\000\000\000",4,1936419184));
}

void EIF_Minit299 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
